@@ -511,10 +511,10 @@ namespace gum {
 } /* namespace gum */
 
 #ifndef GUM_NO_INLINE
-#include <agrum/graphs/nodeGraphPart.inl>
+#include <agrum/graphs/nodeGraphPart_inl.h>
 #endif  // GUM_NOINLINE
 
-#include <agrum/graphs/nodeGraphPart.tcc>
+#include <agrum/graphs/nodeGraphPart_tpl.h>
 
 #endif  // GUM_NODE_GRAPH_PART_H
 
