@@ -139,10 +139,10 @@ namespace gum {
 
 /// include the inlined functions if necessary
 #ifndef GUM_NO_INLINE
-#include <agrum/learning/localSearchWithTabuList.inl>
+#include <agrum/learning/localSearchWithTabuList_inl.h>
 #endif /* GUM_NO_INLINE */
 
 /// always include templated methods
-#include <agrum/learning/localSearchWithTabuList.tcc>
+#include <agrum/learning/localSearchWithTabuList_tpl.h>
 
 #endif /* GUM_LEARNING_LOCAL_SEARCH_WITH_TABU_LIST_H */
