@@ -249,6 +249,6 @@ extern template class gum::learning::ScoreBDeu<>;
 
 
 /// always include the template implementation
-#include <agrum/learning/scores_and_tests/scoreBDeu.tcc>
+#include <agrum/learning/scores_and_tests/scoreBDeu_tpl.h>
 
 #endif /* GUM_LEARNING_SCORE_BDEU_H */
